'''
Data loader for images and sounds.
'''

import os
import pygame
from pygame.locals import *

class Loader():
    def __init__(self):
        self.data_py = os.path.abspath(os.path.dirname(__file__))
        self.data_dir = os.path.normpath(os.path.join(self.data_py, '..', 'data'))

        # sound
        self.sound_table = {"cancel":"cancel.wav", "choice":"choice.wav", "damaged":"damaged.wav", "game over":"game_over.wav"}
        self.sound_dict = {}
        for temp in self.sound_table.items():
            self.sound_dict[temp[0]] = self.load_sound(temp[1])
            self.sound_dict[temp[0]].set_volume(0.7)
    
        # music
        self.load_music('Goto80_-_square_and_enjoy.mp3')

        # font
        self.font_dict = {}
        self.font_dict["main"] = pygame.font.Font(self.__filepath("font/never.ttf"), 28)

        print ("loading is done.")
        
    def get_font(self, name):
        return self.font_dict[name]

    def load_music(self, name):
        path = self.__filepath("sound/"+name)
        return pygame.mixer.music.load(path)

    def load_sound(self, name):
        path = self.__filepath("sound/"+name)
        return pygame.mixer.Sound(path)

    def load_image(self, name, colorkey=None):
        fullname = self.__filepath("image/"+name)
        image = pygame.image.load(fullname)

        image = image.convert()
        if colorkey is not None:
            if colorkey is -1:
                colorkey = image.get_at((0, 0))
            image.set_colorkey(colorkey, RLEACCEL)
        return image

    def __filepath(self, filename):
        return os.path.join(self.data_dir, filename)
